#!/usr/bin/ruby
### $LOAD_PATH << Dir.pwd + '/lib' << Dir.pwd + '/ext'
instdir = 'debian/ruby-libxml'
$LOAD_PATH.map {|path| '%s/%s/%s' % [Dir.pwd, instdir, path]}.
  select {|path| File.exist?(path)}.
  each {|path| $LOAD_PATH << path}

#Dir.chdir('test')
#Dir.open('.').select {|f| f=~/\.rb$/}.each do |f|
#  begin
#    require f
#  rescue
#    'Error loading test: %s' % f
#  end
#end
require "test/test_suite.rb"
